==> lxqt-admin_1.3.0.orig.tar.xz: lxqt-admin-1.3.0/lxqt-admin-user/translations/lxqt-admin-user_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Gruppeinnstillinger</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Gruppenavn:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>Gruppe-ID:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>Brukere tilhører denne gruppen:</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>Gruppens navn kan ikke være tomt.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Bruker- og gruppeinnstillinger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>&amp;Brukere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation>Innloggingsnavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation>Bruker-ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation>Fullt navn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation>Hjemmemappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Vis systembrukere (kun for avanserte brukere)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Grupper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation>Gruppe-ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation>Medlemmer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <source>Edit properties of the selected item</source>
        <translation>Rediger egenskaper for valg</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Add</source>
        <translation>Legg til</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="164"/>
        <source>Add new users or groups</source>
        <translation>Legg til nye brukere eller grupper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <source>Delete selected item</source>
        <translation>Slett valgte</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Properties</source>
        <translation>Egenskaper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>Refresh</source>
        <translation>Frisk opp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Refresh the lists</source>
        <translation>Frisk opp listene</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Change Password</source>
        <translation>Forandre passord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>Change password for the selected user or group</source>
        <translation>Forandre passord for valgt bruker eller gruppe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <location filename="../mainwindow.cpp" line="189"/>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Confirm</source>
        <translation>Bekreft</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Er du sikker på at du vil slette den valgte brukeren?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Er du sikker på at du vil slette den valgte gruppen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>Input the new password for %1:</source>
        <translation>Skriv inn det nye passordet til %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Er du sikker på at du vil bruke et tomt passord?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Brukerinnstillinger</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Fullt navn:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Innloggingsnavn:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>Bruker-ID:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation>Forvalgt</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Hovedgruppe:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Grupper</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>Brukeren tilhører følgende grupper:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Avansert</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Innloggingsshell:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Hjemmemappe:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>The user name cannot be empty.</source>
        <translation>Brukernavnet kan ikke være tomt.</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../usermanager.cpp" line="227"/>
        <source>lxqt-admin-user</source>
        <translation>lxqt administratorbruker</translation>
    </message>
    <message>
        <location filename="../usermanager.cpp" line="228"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;Handlingen (%1) mislyktes:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>

==> lxqt-admin_2.1.0.orig.tar.xz: lxqt-admin-2.1.0/lxqt-admin-user/translations/lxqt-admin-user_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Gruppeinnstillinger</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Gruppenavn:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>Gruppe-ID:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>Brukere tilhører denne gruppen:</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>Gruppens navn kan ikke være tomt.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Bruker- og gruppeinnstillinger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>&amp;Brukere</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation>Innloggingsnavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation>Bruker-ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation>Fullt navn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation>Gruppe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation>Hjemmemappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Vis systembrukere (kun for avanserte brukere)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Grupper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation>Gruppe-ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation>Medlemmer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <source>Edit properties of the selected item</source>
        <translation>Rediger egenskaper for valgt element</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Add</source>
        <translation>Legg til</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="164"/>
        <source>Add new users or groups</source>
        <translation>Legg til nye brukere eller grupper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <source>Delete selected item</source>
        <translation>Slett valgte element</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Properties</source>
        <translation>Egenskaper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>Refresh</source>
        <translation>Gjenoppfrisk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Refresh the lists</source>
        <translation>Gjenoppfrisk listene</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Change Password</source>
        <translation>Forandre passord</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>Change password for the selected user or group</source>
        <translation>Forandre passord for valgt bruker eller gruppe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>Confirm</source>
        <translation>Bekreft</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Er du sikker på at du vil slette den valgte brukeren?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Er du sikker på at du vil slette den valgte gruppen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="202"/>
        <source>Input the new password for %1:</source>
        <translation>Skriv inn det nye passordet til %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Er du sikker på at du vil bruke et tomt passord?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Brukerinnstillinger</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Fullt navn:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Innloggingsnavn:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>Bruker-ID:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation>Forvalgt</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Hovedgruppe:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Grupper</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>Brukeren tilhører følgende grupper:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Avansert</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Innloggingsshell:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Hjemmemappe:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>The user name cannot be empty.</source>
        <translation>Brukernavnet kan ikke være tomt.</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../usermanager.cpp" line="229"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;Handlingen (%1) mislyktes:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>
